@@ -7,6 +7,7 @@ from sqlalchemy import Column
 from sqlalchemy.types import String, UnicodeText
 
 from . import Base, DBSession
+from pyrone.lib import cache
 
 log = logging.getLogger(__name__)
 
@@ -21,32 +22,33 @@ class Config(Base):
         self.id = id
         self.value = value
 
-# internal cache for setting values
-_cache = dict()
-
 # config values are cached
 
 def get_all():
+    """
+    Fetch all config options, not cached
+    """
     dbsession = DBSession()
     all = dbsession.query(Config).all()
     return all
 
-def get(id):
-    if id not in _cache:
+def get(key, force=False):
+    """
+    Get settings value, set "force" to True to update corresponding value in the cache
+    """
+    value = cache.get_value(key)
+    if value is None or force==False:
         dbsession = DBSession()
-        c = dbsession.query(Config).get(id)
+        c = dbsession.query(Config).get(key)
         if c is not None:
             v = c.value
-            if id == 'timezone':
+            if key == 'timezone':
                 v = pytz.timezone(v)
-            _cache[id] = v
-                
+            cache.set_value(key, v)
         
-    log.debug('DDDDDDDDDDDDD %s' % id)
-    log.debug(_cache)
-    return _cache[id]
+    return cache.get_value(key)
 
-def set(id, value, dbsession=None):
+def set(key, value, dbsession=None):
     is_transaction = False
     
     if dbsession is None:
@@ -54,9 +56,9 @@ def set(id, value, dbsession=None):
         is_transaction = True
         transaction.begin()
         
-    c = dbsession.query(Config).get(id)
+    c = dbsession.query(Config).get(key)
     if c is None:
-        c = Config(id, value)
+        c = Config(key, value)
         dbsession.add(c)
     else:
         c.value = value
@@ -64,10 +66,4 @@ def set(id, value, dbsession=None):
     if is_transaction:
         transaction.commit()
 
-    #if commit:
-    #    Session.commit()
-    
-def clear_cache():
-    log.debug('CLEAR CACHE')
-    _cache.clear()
-    log.debug(_cache)
+    cache.set_value(key, value)
