@@ -14,7 +14,7 @@ from webhelpers.feedgenerator import Rss201rev2Feed
 from pyramid.response import Response
 from pyramid.view import view_config
 from pyramid.url import route_url
-from pyramid.httpexceptions import HTTPBadRequest, HTTPFound, HTTPNotFound, HTTPServerError
+from pyramid.httpexceptions import HTTPBadRequest, HTTPFound, HTTPNotFound, HTTPServerError, HTTPMovedPermanently
 from pyramid.renderers import render
 
 from pyrone.models import DBSession, Article, Comment, Tag, File, VerifiedEmail
@@ -121,12 +121,12 @@ def tag_articles(request):
     
     c['prev_page'] = None
     if len(c['articles']) > page_size:
-        c['prev_page'] = route_url('blog_latest', request, _query=[('start', start_page+1)])
+        c['prev_page'] = route_url('blog_latest', request, _query=[('start', start_page+1), ('tag', tag)])
         c['articles'].pop()
         
     c['next_page'] = None
     if start_page > 0:
-        c['next_page'] = route_url('blog_latest', request, _query=[('start', start_page-1)])
+        c['next_page'] = route_url('blog_latest', request, _query=[('start', start_page-1), ('tag', tag)])
     
     c['page_title'] = _(u'Articles labeled with tag “%s”' % tag)
     
@@ -467,6 +467,13 @@ def go_article(request):
     
     return _view_article(request, article_id=article_id)
 
+@view_config(route_name='blog_view_article_slash', renderer='/blog/view_article.mako')
+def view_article_slash(request):
+    shortcut_date = request.matchdict['shortcut_date']
+    shortcut = request.matchdict['shortcut']
+    return HTTPMovedPermanently(request.route_url('blog_view_article', 
+        shortcut_date=shortcut_date, shortcut=shortcut))
+
 @view_config(route_name='blog_view_article', renderer='/blog/view_article.mako')
 def view_article(request):
     shortcut_date = request.matchdict['shortcut_date']
@@ -830,7 +837,7 @@ def download_file(request):
         dltype = request.GET['dltype']
         
     if dltype == 'download':
-        headers.append( ('Content-Disposition', 'attachment; filename=%s' % file.name) )
+        headers.append( ('Content-Disposition', str('attachment; filename=%s' % file.name)) )
     else: #if file.dltype == 'auto':
         pass
     
@@ -872,7 +879,7 @@ def download_file_preview(request):
         dltype = request.GET['dltype']
         
     if dltype == 'download':
-        headers.append( ('Content-Disposition', 'attachment; filename=preview_%s' % file.name) )
+        headers.append( ('Content-Disposition', str('attachment; filename=preview_%s' % file.name)) )
 
     storage_dirs = get_storage_dirs()
     full_path = os.path.join(storage_dirs['orig'], filename)
@@ -906,7 +913,7 @@ def download_file_preview(request):
     except IOError:
         return HTTPNotFound()
     
-    response = Response(content_type=file.content_type)
+    response = Response(content_type=str(file.content_type))
     try:
         response.app_iter = open(preview_path, 'rb')
     except IOError:
